module Truth
  # Client contains the business logic
  class Client
    attr_accessor :config
    def initialize(config)
      self.config = config
    end

    # this is the entry point for the client
    # channel can look like:
    # truth-req.hostname.*
    # truth-req.all.*
    def execute_command(channel, message)
      begin
        response = case Client.get_command(channel)
        when :add_roles
          add_roles(message)
        when :remove_roles
          remove_roles(message)
        when :add_info
          add_info(message)
        when :remove_info
          remove_info(message)
        when :set_environment
          set_environment(message)
        else
          puts "no command for #{channel} available"
          'NOT AVAILABLE'
        end
      rescue Exception => e
        puts "ERROR: #{e}"
        response = "ERROR"
      end
      response
    end

    def self.get_command(channel)
      case channel
      when /add_roles$/       then :add_roles
      when /remove_roles$/    then :remove_roles
      when /add_info$/        then :add_info
      when /remove_info$/     then :remove_info
      when /set_environment$/ then :set_environment
      end
    end

    #### here is the logic implementation

    # add an roles array to the roles for this node
    # message is a comma-separated string
    def add_roles(message)
      roles = message.split(',').map{|x| x.strip}
      config.add_roles roles
      return config.current_roles
    end

    # removes an roles array from the roles for this node.
    # **message** is a comma-separated string
    def remove_roles(message)
      roles = message.split(',').map{|x| x.strip}
      config.remove_roles roles
      return config.current_roles
    end

    # add meta info to be used by your configuration management
    def add_info(message)
      key, value = message.split(',', 2)
      config.add_info key, value.strip
    end

    def remove_info(message)
      config.remove_info message.strip
    end

    # this can change the environment for this node
    def set_environment(message)

    end
  end
end