module Truth
  class Config
    attr_accessor :config_folder
    def initialize(folder = '/etc/truth')
      self.config_folder = folder
    end

    def redis_ip
      self.config['redis_ip']
    end

    def environment
      self.config['environment']
    end

    # reads the systems hostname, can be overridden in the config.yml
    def hostname
      self.config['hostname'] || `hostname`.strip
    end


    def redis_client
      @redis_client ||= EM::Hiredis::Client.connect(redis_ip)
    end

    def add_roles(roles)
      data['roles'] = (current_roles + roles).flatten.uniq
      persist_data
    end

    def remove_roles(roles)
      data['roles'] = (current_roles - roles).flatten.uniq
      persist_data
    end

    def current_roles
      data['roles'] || []
    end

    def data
      @data ||= read_config('data.yml')
    end

    def add_info(key, value)
      data[key] = value
      persist_data
    end

    def remove_info(key)
      data.delete key
      persist_data
    end

    def info(key)
      data[key]
    end

    def data=(obj)
      write_config('data.yml', obj)
    end

    def persist_data
      write_config('data.yml', @data)
    end

    def config
      @config ||= read_config('config.yml')
    end

    def full_config_path(file)
      File.expand_path(File.join(config_folder,file))
    end

    def read_config(filename)
      full_path = File.join(config_folder, filename)
      raise "file #{full_path} not found!" unless File.exist?(full_path)
      return YAML.load(File.read(full_path)) || {}
    end

    def write_config(filename, content)
      full_path = File.join(config_folder, filename)
      raise unless File.exist?(full_path)
      content = YAML.dump(content) unless content.is_a? String
      File.open(full_path, 'w') do |f|
        f.puts content
      end
    end
  end
end
